summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/dialogs/kgameconnectdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/dialogs/kgameconnectdialog.h')
-rw-r--r--libkdegames/kgame/dialogs/kgameconnectdialog.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/libkdegames/kgame/dialogs/kgameconnectdialog.h b/libkdegames/kgame/dialogs/kgameconnectdialog.h
index acbf21d2..fdb0be4f 100644
--- a/libkdegames/kgame/dialogs/kgameconnectdialog.h
+++ b/libkdegames/kgame/dialogs/kgameconnectdialog.h
@@ -30,19 +30,19 @@ class KGameConnectWidget : public QWidget
{
Q_OBJECT
public:
- KGameConnectWidget(QWidget* parent);
+ KGameConnectWidget(TQWidget* parent);
virtual ~KGameConnectWidget();
/**
* @param host The host to connect to by default
**/
- void setHost(const QString& host);
+ void setHost(const TQString& host);
/**
* @return The host to connect to or QString::null if the user wants to
* be the MASTER
**/
- QString host() const;
+ TQString host() const;
/**
* @param port The port that will be shown by default
@@ -66,24 +66,24 @@ public:
* It should be unique for application.
* @since 3.4
**/
- void setType(const QString& type);
+ void setType(const TQString& type);
/**
* @return service type
*/
- QString type() const;
+ TQString type() const;
/**
* Set game name for publishing.
* @param name Game name. Important only for server mode. If not
* set hostname will be used. In case of name conflict -2, -3 and so on will be added to name.
*/
- void setName(const QString& name);
+ void setName(const TQString& name);
/**
* @return game name.
*/
- QString gameName() const;
+ TQString gameName() const;
protected slots:
/**
@@ -108,7 +108,7 @@ private:
* @short Dialog to ask for host and port
*
* This Dialog is used to create a game. You call initConnection(port,
* QString::null, parent, true) to create a network game (as a server)
* or initConnection(port, host, parent) to join a network game.
*
* @author Andreas Beckermann <b_mann@gmx.de>
@@ -117,7 +117,7 @@ class KGameConnectDialog : public KDialogBase
{
Q_OBJECT
public:
- KGameConnectDialog(QWidget* parent = 0,int buttonmask=Ok|Cancel);
+ KGameConnectDialog(TQWidget* parent = 0,int buttonmask=Ok|Cancel);
virtual ~KGameConnectDialog();
/**
@@ -125,23 +125,23 @@ public:
* server game, depending on user's choice.
* @param port The port the user wants to connect to.
* @param host The host the user wants to connect to. Will be
* QString::null if server game is chosen
* @param parent The parent of the dialog
* @param server True to create a network game per default, false to
* join a game by default
**/
- static int initConnection(unsigned short int& port, QString& host, QWidget* parent, bool server = false);
+ static int initConnection(unsigned short int& port, TQString& host, TQWidget* parent, bool server = false);
/**
* @param host The host to connect to by default
**/
- void setHost(const QString& host);
+ void setHost(const TQString& host);
/**
* @return The host to connect to or QString::null if the user wants to
* be the MASTER
**/
- QString host() const;
+ TQString host() const;
/**
* @param port The port that will be shown by default
@@ -30,19 +30,19 @@ class KGameConnectWidget : public QWidget
/**
- * @return The host to connect to or QString::null if the user wants to
+ * @return The host to connect to or TQString::null if the user wants to
* be the MASTER
**/
@@ -108,7 +108,7 @@ private:
*
* This Dialog is used to create a game. You call initConnection(port,
- * QString::null, parent, true) to create a network game (as a server)
+ * TQString::null, parent, true) to create a network game (as a server)
* or initConnection(port, host, parent) to join a network game.
*
@@ -125,23 +125,23 @@ public:
* @param port The port the user wants to connect to.
* @param host The host the user wants to connect to. Will be
- * QString::null if server game is chosen
+ * TQString::null if server game is chosen
* @param parent The parent of the dialog
* @param server True to create a network game per default, false to
@@ -125,23 +125,23 @@ public:
/**
- * @return The host to connect to or QString::null if the user wants to
+ * @return The host to connect to or TQString::null if the user wants to
* be the MASTER
**/